@@ -23,6 +23,7 @@ if(length(logpretty)==1 & length(side)>1){logprettylist=rep(logpretty,length(sid
 if(length(prettybase)==1 & length(side)>1){prettybaselist=rep(prettybase,length(side))}
 if(length(powbase)==1 & length(side)>1){powbaselist=rep(powbase,length(side))}
 if(length(grid)==1 & length(side)>1){gridlist=rep(grid,length(side))}
+if(unlog[1]==''){unloglist=rep(FALSE,length(side))}
 if(unlog[1]=='x'){unloglist=rep(FALSE,length(side));unloglist[side %in% c(1,3)]=TRUE}
 if(unlog[1]=='y'){unloglist=rep(FALSE,length(side));unloglist[side %in% c(2,4)]=TRUE}
 if(unlog[1]=='xy' | unlog[1]=='yx'){unloglist=rep(TRUE,length(side))}
@@ -127,19 +128,15 @@ for(i in 1:length(side)){
 
  		if(logged){
  		  do.call("axis", c(list(side=currentside,at=powbase^major.ticks,tcl=tcl,labels=FALSE,mgp=mgp),dots))
- 		  #axis(side=currentside,at=powbase^major.ticks,tcl=tcl,labels=FALSE,mgp=mgp,col=col.ticks,...)
  		}else{
  		  do.call("axis", c(list(side=currentside,at=major.ticks,tcl=tcl,labels=FALSE,mgp=mgp),dots))
- 		  #axis(side=currentside,at=major.ticks,tcl=tcl,labels=FALSE,mgp=mgp,col=col.ticks,...)
  		}
  		
     if(labels){
       if(logged){
         do.call("axis", c(list(side=currentside,at=powbase^labloc,tick=F,labels=uselabels,mgp=mgp),dots))
-        #axis(side=currentside,at=powbase^labloc,tick=F,labels=uselabels,mgp=mgp,...)
       }else{
         do.call("axis", c(list(side=currentside,at=labloc,tick=F,labels=uselabels,mgp=mgp),dots))
-        #axis(side=currentside,at=labloc,tick=F,labels=uselabels,mgp=mgp,...)
       }
     }
     
@@ -148,10 +145,8 @@ for(i in 1:length(side)){
       minor.ticks = c(outer(minors, major.ticks, `+`))
       if(logged){
         do.call("axis", c(list(side=currentside,at=powbase^minor.ticks,tcl=tcl*ratio,labels=FALSE,mgp=mgp),dots))
-        #axis(side=currentside,at=powbase^minor.ticks,tcl=tcl*ratio,labels=FALSE,col=col.ticks,...)
       }else{
         do.call("axis", c(list(side=currentside,at=minor.ticks,tcl=tcl*ratio,labels=FALSE,mgp=mgp),dots))
-        #axis(side=currentside,at=minor.ticks,tcl=tcl*ratio,labels=FALSE,col=col.ticks,...)
       }
     }
     if(is.null(xlab)==F & currentside==1){mtext(xlab,1,line=mtline,cex=par()$cex.lab)}
